@@ -21,7 +21,6 @@ import logging
 from .parameters import Parameter
 from .random_variables import (
     Distribution,
-    ModelPerturbationKernel,
     RV,
     RVBase,
     RVDecorator,
@@ -75,7 +74,7 @@ from .sampler import (
     RedisEvalParallelSampler,
     MulticoreEvalParallelSampler,
     ConcurrentFutureSampler)
-from .smc import ABCSMC
+from .inference import ABCSMC
 from .storage import (
     History,
     create_sqlite_db_id)
@@ -96,7 +95,10 @@ from .transition import (
     MultivariateNormalTransition,
     LocalTransition,
     DiscreteRandomWalkTransition,
-    GridSearchCV)
+    GridSearchCV,
+    AggregatedTransition,
+    DiscreteJumpTransition,
+    ModelPerturbationKernel)
 from .population import (
     Particle,
     Population)
