@@ -1,6 +1,8 @@
 """
-Multi-core and Distributed Sampling
-===================================
+Parallel sampling
+=================
+
+Parallel multi-core and distributed sampling.
 
 The choice of the sampler determines in which way parallelization is performed.
 See also the `explanation of the samplers <sampler.html>`_.
@@ -15,14 +17,3 @@ from .multicore_evaluation_parallel import MulticoreEvalParallelSampler
 from .redis_eps import (RedisEvalParallelSampler,
                         RedisEvalParallelSamplerServerStarter)
 from .concurrent_future import ConcurrentFutureSampler
-
-__all__ = ["Sample",
-           "Sampler",
-           "SingleCoreSampler",
-           "MulticoreParticleParallelSampler",
-           "MappingSampler",
-           "DaskDistributedSampler",
-           "RedisEvalParallelSampler",
-           "MulticoreEvalParallelSampler",
-           "RedisEvalParallelSamplerServerStarter",
-           "ConcurrentFutureSampler"]
