@@ -13,17 +13,17 @@ class SingleCoreSampler(Sampler):
         Whether to check the maximum number of evaluations on the fly.
     """
 
-    def __init__(self, check_max_eval: bool = False):
+    def __init__(
+            self, check_max_eval: bool = False):
         super().__init__()
         self.check_max_eval = check_max_eval
 
     def sample_until_n_accepted(
-            self, n, simulate_one, max_eval=np.inf, all_accepted=False,
-            show_progress=False):
+            self, n, simulate_one, max_eval=np.inf, all_accepted=False):
         nr_simulations = 0
         sample = self._create_empty_sample()
 
-        for _ in jabbar(range(n), enable=show_progress, keep=False):
+        for _ in jabbar(range(n), enable=self.show_progress, keep=False):
             while True:
                 if self.check_max_eval and nr_simulations >= max_eval:
                     break
