@@ -2,11 +2,12 @@ from abc import ABCMeta
 import numpy as np
 import pandas as pd
 import functools
+from typing import Union
 
 
 def wrap_fit(f):
     @functools.wraps(f)
-    def fit(self, X, w):
+    def fit(self, X: pd.DataFrame, w: np.ndarray):
         self.X = X
         self.w = w
         if len(X.columns) == 0:
@@ -22,13 +23,22 @@ def wrap_fit(f):
 
 def wrap_pdf(f):
     @functools.wraps(f)
-    def pdf(self, x):
+    def pdf(self, x: Union[pd.Series, pd.DataFrame]):
         if self.no_parameters:
             return 1
         return f(self, x)
     return pdf
 
 
+def wrap_rvs(f):
+    @functools.wraps(f)
+    def rvs(self, size: int = None):
+        if self.no_parameters:
+            return pd.DataFrame(dtype=float)
+        return f(self, size)
+    return rvs
+
+
 def wrap_rvs_single(f):
     @functools.wraps(f)
     def rvs_single(self):
@@ -48,4 +58,5 @@ class TransitionMeta(ABCMeta):
         ABCMeta.__init__(cls, name, bases, attrs)
         cls.fit = wrap_fit(cls.fit)
         cls.pdf = wrap_pdf(cls.pdf)
+        cls.rvs = wrap_rvs(cls.rvs)
         cls.rvs_single = wrap_rvs_single(cls.rvs_single)
